@@ -5,16 +5,17 @@ from improutils import negative
 
 
 def ocr(img_bin):
-    '''Detects text in the file.
+    """
+    Detects text in the file.
 
     Parameters
     ----------
-    img_bin : numpy.ndarray
+    img_bin : ndarray
         Input binary image. White objects on black background.
     Returns
     -------
-    Text on image.
-    '''
+    The recognized text in the image.
+    """
     # Tesseract works with black objects on white background.
     img_bin = negative(img_bin)
-    return pytesseract.image_to_string(PIL.Image.fromarray(img_bin))
\ No newline at end of file
+    return pytesseract.image_to_string(PIL.Image.fromarray(img_bin))
